lilypondparsertools.LilyPondDuration
====================================

.. abjad-lineage:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration

.. autoclass:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.storage_format
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__eq__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__ge__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__gt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__le__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__lt__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__ne__
   :noindex:

.. automethod:: abjad.tools.lilypondparsertools.LilyPondDuration.LilyPondDuration.LilyPondDuration.__repr__
   :noindex:
